==> openshift-model-monitoring-5.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.Object;

 /**
  * Generated
  */
public class PrometheusFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<A>{
  public PrometheusFluentImpl() {
  }
  public PrometheusFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.Prometheus instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder spec;
  private io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder status;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(java.lang.Integer availableReplicas,java.lang.Boolean paused,java.lang.Integer replicas,java.lang.Integer unavailableReplicas,java.lang.Integer updatedReplicas) {
    return (A)withStatus(new PrometheusStatus(availableReplicas, paused, replicas, unavailableReplicas, updatedReplicas));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PrometheusFluentImpl that = (PrometheusFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) PrometheusFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class SpecNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder builder;
    public N and() {
      return (N) PrometheusFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder builder;
    public N and() {
      return (N) PrometheusFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class PrometheusFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent<A>{
  public PrometheusFluentImpl() {
  }
  public PrometheusFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.Prometheus instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder spec;
  private io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder status;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec getSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec buildSpec() {
    return this.spec!=null?this.spec.build():null;
  }
  public A withSpec(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> withNewSpec() {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.SpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.SpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus getStatus() {
    return this.status!=null?this.status.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus buildStatus() {
    return this.status!=null?this.status.build():null;
  }
  public A withStatus(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(java.lang.Integer availableReplicas,java.lang.Boolean paused,java.lang.Integer replicas,java.lang.Integer unavailableReplicas,java.lang.Integer updatedReplicas) {
    return (A)withStatus(new PrometheusStatus(availableReplicas, paused, replicas, unavailableReplicas, updatedReplicas));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> withNewStatus() {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.StatusNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluentImpl.StatusNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PrometheusFluentImpl that = (PrometheusFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) PrometheusFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  public class SpecNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SpecNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpec item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.PrometheusSpecBuilder builder;
    public N and() {
      return (N) PrometheusFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  public class StatusNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.PrometheusFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatusNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatus item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.PrometheusStatusBuilder builder;
    public N and() {
      return (N) PrometheusFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
